@@ -177,8 +177,8 @@ es_from_means_sd_pre_post <- function(mean_pre_exp, mean_exp, mean_pre_sd_exp, m
 
   es$md <- ifelse(reverse_means_pre_post, md_nexp - md_exp, md_exp - md_nexp)
   es$md_se <- sqrt(md_var_exp + md_var_nexp)
-  es$md_ci_lo <- es$md - sqrt(es$md_se) * qt(.975, n_exp + n_nexp - 2)
-  es$md_ci_up <- es$md + sqrt(es$md_se) * qt(.975, n_exp + n_nexp - 2)
+  es$md_ci_lo <- es$md - es$md_se * qt(.975, n_exp + n_nexp - 2)
+  es$md_ci_up <- es$md + es$md_se * qt(.975, n_exp + n_nexp - 2)
 
   es$info_used <- "means_sd_pre_post"
 
@@ -409,14 +409,14 @@ es_from_means_ci_pre_post <- function(mean_pre_exp, mean_exp,
   tryCatch({
     .validate_ci_symmetry(mean_pre_exp, mean_pre_ci_lo_exp, mean_pre_ci_up_exp,
                           func = "es_from_means_ci_pre_post",
-                          max_asymmetry_percent = 5)
+                          max_asymmetry_percent = max_asymmetry)
   }, error = function(e) {
     stop("Validation failed: ", conditionMessage(e), "\n")
   })
   tryCatch({
     .validate_ci_symmetry(mean_pre_nexp, mean_pre_ci_lo_nexp, mean_pre_ci_up_nexp,
                           func = "es_from_means_ci_pre_post",
-                          max_asymmetry_percent = 5)
+                          max_asymmetry_percent = max_asymmetry)
   }, error = function(e) {
     stop("Validation failed: ", conditionMessage(e), "\n")
   })
