@@ -205,6 +205,7 @@
   # we start by the first ES requested, and if NA, try the second one, etc...
   for (i in 1:length(ordering)) {
     # i = 1
+    # print(i);
     # print(ordering[i]);
     df_temp <- list_df_restrict[[which(df_info_min_max[1, ] == ordering[i])]]
     row <- which(
@@ -245,8 +246,7 @@
       # print(col)
       # for a given information, if a calculation (ES or SE) failed, we delete the others (CI are necessarily NA)----------------------------
       if ((!is.na(df_value_min_max[row, col]) & is.na(df_se_min_max[row, col]) & measure != "nnt") |
-        (is.na(df_value_min_max[row, col]) & !is.na(df_se_min_max[row, col])) |
-        (!is.na(df_value_min_max[row, col]) & is.na(df_se_min_max[row, col]) & measure == "nnt")) {
+        (is.na(df_value_min_max[row, col]) & !is.na(df_se_min_max[row, col]))) {
         df_value_min_max[row, col] <- df_se_min_max[row, col] <- NA
       }
       # we identify all information from which we can derive an effect size ----------------------------
@@ -291,6 +291,9 @@
   col_min <- apply(df_value_min_max, 1, function(x) which.min(x)[1])
   col_max <- apply(df_value_min_max, 1, function(x) which.max(x)[1])
 
+  cols_equal = which(col_min == col_max)
+  col_min[cols_equal] <- apply(data.frame(df_ci_lo_min_max)[cols_equal, ], 1, function(x) which.min(x)[1])
+  col_max[cols_equal] <- apply(data.frame(df_ci_lo_min_max)[cols_equal, ], 1, function(x) which.max(x)[1])
 
   for (i in 1:length(col_min)) {
     x[i, paste0("min_info", suffix)] <- df_info_min_max[i, col_min[i]]
